# ========================================================================================================================================================
# Database Sub Farmacia-1 v1 (PA), 2022-09-07
# ========================================================================================================================================================

# Cambiar el nombre de la base de datos segun la institucio ej: (bdsalmi_es_santotomas) ==================================================================
USE bdsalmi_es;

# Estructura de la tabla TblBloqueoSub1 ==================================================================================================================

CREATE TABLE TblBloqueoSub1 (
  BloSts TINYINT NOT NULL, 
  SelId INTEGER NOT NULL, 
  UsuId INTEGER NOT NULL, 
  LotId INTEGER NOT NULL, 
  BloCan INTEGER NOT NULL
) 
ENGINE=InnoDB;

# Estructura de la tabla TblConfiguracionesSub1 ==========================================================================================================

CREATE TABLE TblConfiguracionesSub1 (
  ConId INTEGER NOT NULL AUTO_INCREMENT, 
  ConNom VARCHAR(100) NOT NULL, 
  ConSts VARCHAR(50) NOT NULL, 
  PRIMARY KEY (ConId)
) 
ENGINE=InnoDB;

# Estructura de la tabla TblEntradasSub1 =================================================================================================================

CREATE TABLE TblEntradasSub1 (
  EntId INTEGER NOT NULL AUTO_INCREMENT, 
  ProId INTEGER NOT NULL, 
  RepId INTEGER NOT NULL, 
  EntDoc VARCHAR(20) NOT NULL, 
  DisId INTEGER NOT NULL, 
  ModCod INTEGER NOT NULL, 
  MvsId INTEGER NOT NULL, 
  ObsId INTEGER NOT NULL, 
  UsuId INTEGER NOT NULL, 
  EntAct TINYINT NOT NULL,
  PRIMARY KEY (EntId)
) 
ENGINE=InnoDB;

INSERT INTO TblEntradasSub1 (EntId, ProId, RepId, EntDoc, DisId, ModCod, MvsId, ObsId, UsuId, EntAct) 
VALUES (0, 0, 0, '0', 0, 0, 0, 0, 0, 0);

UPDATE TblEntradasSub1 SET EntId = 0 WHERE EntId = 1;

ALTER TABLE TblEntradasSub1 AUTO_INCREMENT = 1;

# Estructura de la tabla TblEtiquetasSub1 ================================================================================================================

CREATE TABLE TblEtiquetasSub1 (
  SalId INTEGER NOT NULL, 
  SelId INTEGER NOT NULL, 
  EtiDos DECIMAL(11,4) NOT NULL, 
  FreId INTEGER NOT NULL, 
  ViaId INTEGER NOT NULL, 
  EtiDia INTEGER NOT NULL, 
  EtiDir VARCHAR(250) NOT NULL, 
  EtiNot VARCHAR(250) NOT NULL, 
  INDEX (EtiDir), 
  INDEX (EtiNot)
) 
ENGINE=InnoDB;

# Estructura de la tabla TblFraccionesSub1 ===============================================================================================================

CREATE TABLE TblFraccionesSub1 (
  FraId INTEGER NOT NULL AUTO_INCREMENT, 
  MvsId INTEGER NOT NULL, 
  SelId INTEGER NOT NULL, 
  FueId INTEGER NOT NULL, 
  EntId INTEGER NOT NULL, 
  PosId INTEGER NOT NULL, 
  SalId INTEGER NOT NULL, 
  NegId INTEGER NOT NULL, 
  FraEnt INTEGER NOT NULL, 
  FraPos INTEGER NOT NULL, 
  FraSal INTEGER NOT NULL, 
  FraNeg INTEGER NOT NULL, 
  FraCos DECIMAL(11,4) NOT NULL, 
  LotId INTEGER NOT NULL, 
  FraRec INTEGER NOT NULL, 
  FraFch DATE NOT NULL, 
  UsuId INTEGER NOT NULL, 
  FraAct TINYINT NOT NULL, 
  INDEX (MvsId), 
  INDEX (SelId), 
  INDEX (EntId), 
  INDEX (PosId), 
  INDEX (SalId), 
  INDEX (NegId), 
  INDEX (FraFch),  
  PRIMARY KEY (FraId)
) 
ENGINE=InnoDB;

# Estructura de la tabla TblLotesSub1 ====================================================================================================================

CREATE TABLE TblLotesSub1 (
  LotId INTEGER NOT NULL AUTO_INCREMENT, 
  LotNro VARCHAR(20) NOT NULL, 
  LotVto DATE NOT NULL, 
  LotCos DECIMAL(11,4) NOT NULL, 
  UsuId INTEGER NOT NULL, 
  LotAct TINYINT NOT NULL, 
  INDEX (LotNro), 
  PRIMARY KEY (LotId)
) 
ENGINE=InnoDB;

INSERT INTO TblLotesSub1 (LotId, LotNro, LotVto, LotCos, UsuId, LotAct) 
VALUES (0, '0', '2000-01-01', '0', 0, 0);

UPDATE TblLotesSub1 SET LotId = 0 WHERE LotId = 1;

ALTER TABLE TblLotesSub1 AUTO_INCREMENT = 1;

# Estructura de la tabla TblMensualesSub1 ================================================================================================================

CREATE TABLE TblMensualesSub1 (
  MenId INTEGER NOT NULL AUTO_INCREMENT, 
  MenNro TINYINT NOT NULL, 
  MenMes VARCHAR(20) NOT NULL, 
  MenCon TINYINT NOT NULL, 
  MenMax DECIMAL(3,1) NOT NULL, 
  MenMin DECIMAL(3,1) NOT NULL, 
  MenFch DATE NOT NULL, 
  GesId INTEGER NOT NULL, 
  UsuId INTEGER NOT NULL, 
  INDEX (MenMes), 
  PRIMARY KEY (MenId)
) 
ENGINE=InnoDB;

# Estructura de la tabla TblMensualSub1 ==================================================================================================================

CREATE TABLE TblMensualSub1 (
  MenId INTEGER NOT NULL, 
  SelId INTEGER NOT NULL, 
  MenSM INTEGER NOT NULL, 
  MenRM INTEGER NOT NULL, 
  MenCM INTEGER NOT NULL, 
  MenAP INTEGER NOT NULL, 
  MenAN INTEGER NOT NULL, 
  MenCP INTEGER NOT NULL, 
  MenDI INTEGER NOT NULL, 
  MenME VARCHAR(10) NOT NULL, 
  MenMU VARCHAR(10) NOT NULL, 
  MenCS INTEGER NOT NULL, 
  MenCO DECIMAL(11,2) NOT NULL, 
  INDEX (MenId), 
  INDEX (SelId)
) 
ENGINE=InnoDB;

# Estructura de la tabla TblMovimientoSub1 ===============================================================================================================

CREATE TABLE TblMovimientoSub1 (
  MovId INTEGER NOT NULL AUTO_INCREMENT, 
  MvsId INTEGER NOT NULL, 
  SelId INTEGER NOT NULL, 
  FueId INTEGER NOT NULL, 
  EntId INTEGER NOT NULL, 
  PosId INTEGER NOT NULL, 
  SalId INTEGER NOT NULL, 
  NegId INTEGER NOT NULL, 
  MovEnt INTEGER NOT NULL, 
  MovPos INTEGER NOT NULL, 
  MovSal INTEGER NOT NULL, 
  MovNeg INTEGER NOT NULL, 
  MovSdo INTEGER NOT NULL, 
  MovCos DECIMAL(11,4) NOT NULL, 
  LotId INTEGER NOT NULL, 
  MovRec INTEGER NOT NULL, 
  MovFch DATE NOT NULL, 
  UsuId INTEGER NOT NULL, 
  MovAct TINYINT NOT NULL, 
  INDEX (MvsId), 
  INDEX (SelId), 
  INDEX (EntId), 
  INDEX (PosId), 
  INDEX (SalId), 
  INDEX (NegId), 
  INDEX (MovFch),  
  PRIMARY KEY (MovId)
) 
ENGINE=InnoDB;

# Estructura de la tabla TblNegativosSub1 ================================================================================================================

CREATE TABLE TblNegativosSub1 (
  NegId INTEGER NOT NULL AUTO_INCREMENT, 
  RecId INTEGER NOT NULL, 
  RepId INTEGER NOT NULL, 
  MvsId INTEGER NOT NULL, 
  ObsId INTEGER NOT NULL, 
  UsuId INTEGER NOT NULL, 
  NegAct TINYINT NOT NULL,
  PRIMARY KEY (NegId)
) 
ENGINE=InnoDB;

INSERT INTO TblNegativosSub1 (NegId, RecId, RepId, MvsId, ObsId, UsuId, NegAct) 
VALUES (0, 0, 0, 0, 0, 0, 0);

UPDATE TblNegativosSub1 SET NegId = 0 WHERE NegId = 1;

ALTER TABLE TblNegativosSub1 AUTO_INCREMENT = 1;

# Estructura de la tabla TblPositivosSub1 ================================================================================================================

CREATE TABLE TblPositivosSub1 (
  PosId INTEGER NOT NULL AUTO_INCREMENT, 
  ProId INTEGER NOT NULL, 
  RepId INTEGER NOT NULL, 
  PosDoc VARCHAR(20) NOT NULL, 
  MvsId INTEGER NOT NULL, 
  ObsId INTEGER NOT NULL, 
  UsuId INTEGER NOT NULL, 
  PosAct TINYINT NOT NULL, 
  INDEX (PosDoc), 
  PRIMARY KEY (PosId)
) 
ENGINE=InnoDB;

INSERT INTO TblPositivosSub1 (PosId, ProId, RepId, PosDoc, MvsId, ObsId, UsuId, PosAct) 
VALUES (0, 0, 0, '0', 0, 0, 0, 0);

UPDATE TblPositivosSub1 SET PosId = 0 WHERE PosId = 1;

ALTER TABLE TblPositivosSub1 AUTO_INCREMENT = 1;

# Estructura de la tabla TblRelacionSalDiaSub1 ===========================================================================================================

CREATE TABLE TblRelacionSalDiaSub1 (
  SalId INTEGER NOT NULL, 
  DiaId INTEGER NOT NULL, 
  DiaCos DECIMAL(11,4) NOT NULL, 
  DiaNro TINYINT NOT NULL, 
  DiaFch DATE NOT NULL
) 
ENGINE=InnoDB;

# Estructura de la tabla TblSalidasSub1 ==================================================================================================================

CREATE TABLE TblSalidasSub1 (
  SalId INTEGER NOT NULL AUTO_INCREMENT, 
  SalDoc VARCHAR(20) NOT NULL, 
  FueId INTEGER NOT NULL, 
  SerId INTEGER NOT NULL, 
  PacId INTEGER NOT NULL, 
  DsrId INTEGER NOT NULL, 
  PsrId INTEGER NOT NULL, 
  RepId INTEGER NOT NULL, 
  SalAno TINYINT NOT NULL, 
  SalMes TINYINT NOT NULL, 
  SalDia TINYINT NOT NULL, 
  SalTot DECIMAL(11,4) NOT NULL, 
  SalFch DATE NOT NULL, 
  SalAte DATE NOT NULL, 
  MvsId INTEGER NOT NULL, 
  ObsId INTEGER NOT NULL, 
  UsuId INTEGER NOT NULL, 
  SalAct TINYINT NOT NULL, 
  INDEX (SalDoc), 
  INDEX (SalAno), 
  INDEX (SalMes), 
  INDEX (SalDia), 
  INDEX (SalFch), 
  PRIMARY KEY (SalId)
) 
ENGINE=InnoDB;

INSERT INTO TblSalidasSub1 (SalId, SalDoc, FueId, SerId, PacId, DsrId, PsrId, RepId, SalAno, SalMes, SalDia, SalTot, SalFch, SalAte, MvsId, ObsId, UsuId, SalAct) 
VALUES (0, '0', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, '2000-01-01', '2000-01-01', 0, 0, 0, 0);

UPDATE TblSalidasSub1 SET SalId = 0 WHERE SalId = 1;

ALTER TABLE TblSalidasSub1 AUTO_INCREMENT = 1;

# Relaciones de la tabla TblEntradasSub1 =================================================================================================================

ALTER TABLE TblEntradasSub1 ADD CONSTRAINT TblEntradasSub1ProId FOREIGN KEY (ProId) REFERENCES TblProveedores (ProId);
ALTER TABLE TblEntradasSub1 ADD CONSTRAINT TblEntradasSub1RepId FOREIGN KEY (RepId) REFERENCES TblRepresentantes (RepId);
ALTER TABLE TblEntradasSub1 ADD CONSTRAINT TblEntradasSub1MvsId FOREIGN KEY (MvsId) REFERENCES TblMovimientos (MvsId);
ALTER TABLE TblEntradasSub1 ADD CONSTRAINT TblEntradasSub1ObsId FOREIGN KEY (ObsId) REFERENCES TblObservaciones (ObsId);
ALTER TABLE TblEntradasSub1 ADD CONSTRAINT TblEntradasSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);

# Relaciones de la tabla TblEtiquetasSub1 ================================================================================================================

ALTER TABLE TblEtiquetasSub1 ADD CONSTRAINT TblEtiquetasSub1SalId FOREIGN KEY (SalId) REFERENCES TblSalidasSub1 (SalId);
ALTER TABLE TblEtiquetasSub1 ADD CONSTRAINT TblEtiquetasSub1SelId FOREIGN KEY (SelId) REFERENCES TblSeleccion (SelId);
ALTER TABLE TblEtiquetasSub1 ADD CONSTRAINT TblEtiquetasSub1FreId FOREIGN KEY (FreId) REFERENCES TblFrecuencias (FreId);
ALTER TABLE TblEtiquetasSub1 ADD CONSTRAINT TblEtiquetasSub1ViaId FOREIGN KEY (ViaId) REFERENCES TblVias (ViaId);

# Relaciones de la tabla TblFraccionesSub1 ===============================================================================================================

ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1MvsId FOREIGN KEY (MvsId) REFERENCES TblMovimientos (MvsId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1SelId FOREIGN KEY (SelId) REFERENCES TblSeleccion (SelId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1FueId FOREIGN KEY (FueId) REFERENCES TblFuentes (FueId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1EntId FOREIGN KEY (EntId) REFERENCES TblEntradasSub1 (EntId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1PosId FOREIGN KEY (PosId) REFERENCES TblPositivosSub1 (PosId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1SalId FOREIGN KEY (SalId) REFERENCES TblSalidasSub1 (SalId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1NegId FOREIGN KEY (NegId) REFERENCES TblNegativosSub1 (NegId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1LotId FOREIGN KEY (LotId) REFERENCES TblLotesSub1 (LotId);
ALTER TABLE TblFraccionesSub1 ADD CONSTRAINT TblFraccionesSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);

# Relaciones de la tabla TblLotesSub1 ====================================================================================================================

ALTER TABLE TblLotesSub1 ADD CONSTRAINT TblLotesSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);

# Relaciones de la tabla TblMensualSub1 ==================================================================================================================

ALTER TABLE TblMensualSub1 ADD CONSTRAINT TblMensualSub1MenId FOREIGN KEY (MenId) REFERENCES TblMensualesSub1 (MenId);
ALTER TABLE TblMensualSub1 ADD CONSTRAINT TblMensualSub1SelId FOREIGN KEY (SelId) REFERENCES TblSeleccion (SelId);

# Relaciones de la tabla TblMensualesSub1 ================================================================================================================

ALTER TABLE TblMensualesSub1 ADD CONSTRAINT TblMensualesSub1GesId FOREIGN KEY (GesId) REFERENCES TblGestion (GesId);
ALTER TABLE TblMensualesSub1 ADD CONSTRAINT TblMensualesSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);

# Relaciones de la tabla TblMovimientoSub1 ===============================================================================================================

ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1MvsId FOREIGN KEY (MvsId) REFERENCES TblMovimientos (MvsId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1SelId FOREIGN KEY (SelId) REFERENCES TblSeleccion (SelId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1FueId FOREIGN KEY (FueId) REFERENCES TblFuentes (FueId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1EntId FOREIGN KEY (EntId) REFERENCES TblEntradasSub1 (EntId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1PosId FOREIGN KEY (PosId) REFERENCES TblPositivosSub1 (PosId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1SalId FOREIGN KEY (SalId) REFERENCES TblSalidasSub1 (SalId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1NegId FOREIGN KEY (NegId) REFERENCES TblNegativosSub1 (NegId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1LotId FOREIGN KEY (LotId) REFERENCES TblLotesSub1 (LotId);
ALTER TABLE TblMovimientoSub1 ADD CONSTRAINT TblMovimientoSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);

# Relaciones de la tabla TblNegativosSub1 ================================================================================================================

ALTER TABLE TblNegativosSub1 ADD CONSTRAINT TblNegativosSub1RecId FOREIGN KEY (RecId) REFERENCES TblReceptores (RecId);
ALTER TABLE TblNegativosSub1 ADD CONSTRAINT TblNegativosSub1RepId FOREIGN KEY (RepId) REFERENCES TblRepresentantes (RepId);
ALTER TABLE TblNegativosSub1 ADD CONSTRAINT TblNegativosSub1MvsId FOREIGN KEY (MvsId) REFERENCES TblMovimientos (MvsId);
ALTER TABLE TblNegativosSub1 ADD CONSTRAINT TblNegativosSub1ObsId FOREIGN KEY (ObsId) REFERENCES TblObservaciones (ObsId);
ALTER TABLE TblNegativosSub1 ADD CONSTRAINT TblNegativosSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);

# Relaciones de la tabla TblPositivosSub1 ================================================================================================================

ALTER TABLE TblPositivosSub1 ADD CONSTRAINT TblPositivosSub1ProId FOREIGN KEY (ProId) REFERENCES TblProveedores (ProId);
ALTER TABLE TblPositivosSub1 ADD CONSTRAINT TblPositivosSub1RepId FOREIGN KEY (RepId) REFERENCES TblRepresentantes (RepId);
ALTER TABLE TblPositivosSub1 ADD CONSTRAINT TblPositivosSub1MvsId FOREIGN KEY (MvsId) REFERENCES TblMovimientos (MvsId);
ALTER TABLE TblPositivosSub1 ADD CONSTRAINT TblPositivosSub1ObsId FOREIGN KEY (ObsId) REFERENCES TblObservaciones (ObsId);
ALTER TABLE TblPositivosSub1 ADD CONSTRAINT TblPositivosSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);

# Relaciones de integridad referencial TblRelacionSalDiaSub1 =============================================================================================

ALTER TABLE TblRelacionSalDiaSub1 ADD CONSTRAINT TblRelacionSalDiaSub1SalId FOREIGN KEY (SalId) REFERENCES TblSalidasSub1 (SalId);
ALTER TABLE TblRelacionSalDiaSub1 ADD CONSTRAINT TblRelacionSalDiaSub1DiaId FOREIGN KEY (DiaId) REFERENCES TblDiagnosticos (DiaId);

# Relaciones de la tabla TblSalidasSub1 ==================================================================================================================

ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1FueId FOREIGN KEY (FueId) REFERENCES TblFuentes (FueId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1SerId FOREIGN KEY (SerId) REFERENCES TblServicios (SerId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1PacId FOREIGN KEY (PacId) REFERENCES TblPacientes (PacId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1DsrId FOREIGN KEY (DsrId) REFERENCES TblDispensadores (DsrId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1PsrId FOREIGN KEY (PsrId) REFERENCES TblPrescriptores (PsrId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1RepId FOREIGN KEY (RepId) REFERENCES TblRepresentantes (RepId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1MvsId FOREIGN KEY (MvsId) REFERENCES TblMovimientos (MvsId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1ObsId FOREIGN KEY (ObsId) REFERENCES TblObservaciones (ObsId);
ALTER TABLE TblSalidasSub1 ADD CONSTRAINT TblSalidasSub1UsuId FOREIGN KEY (UsuId) REFERENCES TblUsuarios (UsuId);